@@ -1,7 +1,7 @@
 package Dir::Write::Rotate;
 
-our $DATE = '2017-06-24'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-06-26'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -206,14 +206,14 @@ Dir::Write::Rotate - Write files to a directory, with rotate options
 
 =head1 VERSION
 
-This document describes version 0.002 of Dir::Write::Rotate (from Perl distribution Dir-Write-Rotate), released on 2017-06-24.
+This document describes version 0.003 of Dir::Write::Rotate (from Perl distribution Dir-Write-Rotate), released on 2017-06-26.
 
 =head1 SYNOPSIS
 
  use Dir::Write::Rotate;
 
  my $dwr = Dir::Write::Rotate->new(
-     name               => 'somedir.log',            # required
+     path               => 'somedir.log',            # required
      filename_pattern   => '%Y-%m-%d-%H%M%S.pid-%{pid}.%{ext}', # optional
      filename_sub       => sub { ... },              # optional
      max_size           => undef,                    # optional
